# [Alibaba Cloud API](http://aliyun-api.hive.pt)

Python API client for the Alibaba Cloud services.

## Configuration

* `ALIYUN_BASE_URL` (`str`) - The base URL to be used for the API calls (defaults to `https://oss-cn-beijing.aliyuncs.com/`)
* `ALIYUN_ACCESS_KEY` (`str`) - Secret key to be used to authenticate API request (defaults to `None`)
* `ALIYUN_SECRET` (`str`) - String value to be kept secret and used in the request signing process as the secret key (defaults to `None`)

## License

Alibaba Cloud API is currently licensed under the [Apache License, Version 2.0](http://www.apache.org/licenses/).

## Build Automation

[![Build Status](https://travis-ci.org/hivesolutions/aliyun_api.svg?branch=master)](https://travis-ci.org/hivesolutions/aliyun_api)
[![Coverage Status](https://coveralls.io/repos/hivesolutions/aliyun_api/badge.svg?branch=master)](https://coveralls.io/r/hivesolutions/aliyun_api?branch=master)
[![PyPi Status](https://img.shields.io/pypi/v/aliyun_api.svg)](https://pypi.python.org/pypi/aliyun_api)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://www.apache.org/licenses/)
